package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Mar 28, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ImportExportRequest struct {
TarFile string `json:"tar"`
Target string `json:"target"`
IgnoreSSL bool `json:"ignore_ssl"`
}
type PackageInfo struct {
ImageName string `json:"image_name_tag"`
TarPath string `json:"tar_path"`
Status string `json:"status"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.